# mainly copied from
# https://techoverflow.net/2018/01/16/downloading-reading-a-zip-file-in-memory-using-python/

import requests
import io
import zipfile


def download_extract_zip(url, unzip_dir):
    """
    Download a ZIP file and extract its contents in memory
    yields (filename, file-like object) pairs
    """
    response = requests.get(url)
    with zipfile.ZipFile(io.BytesIO(response.content)) as zipfile_object:
        zipfile_object.extractall(unzip_dir)



from tokenizers_collection.tokenizers import (
    tokenizer_jieba,
    tokenizer_thulac,
    tokenizer_nlpir,
    tokenizer_ltp
)

tokenizer_registry = {
    'jieba': tokenizer_jieba,
    'thulac': tokenizer_thulac,
    'nlpir': tokenizer_nlpir,
    'ltp': tokenizer_ltp
}



import os

import jieba
import thulac
import pynlpir
from pyltp import Segmentor

from tokenizers_collection.helper import get_ltp_data_file

pynlpir.open()

segmentor = Segmentor()
ltp_data_file = get_ltp_data_file()
segmentor.load(ltp_data_file)


def tokenizer_jieba(input_file, output_file, delim="  "):
    with open(input_file, 'r') as fp, open(output_file, 'w') as output_fd:
        output_lines = []
        for raw_line in fp:
            line = raw_line.strip()
            result = delim.join(jieba.cut(line, cut_all=False, HMM=True))

            result_with_new_line = result + "\n"

            output_lines.append(result_with_new_line)

        output_fd.writelines(output_lines)


def tokenizer_thulac(input_file, output_file, delim=" "):
    thu1 = thulac.thulac(seg_only=True)   # 只进行分词，不进行词性标注
    thu1.cut_f(input_file, output_file)   # 对input.txt文件内容进行分词，输出到output.txt


def tokenizer_nlpir(input_file, output_file, delim=" ", corpus=None):
    with open(input_file, 'r') as fp, open(output_file, 'w') as output_fd:
        output_lines = []
        for raw_line in fp:
            line = raw_line.strip()
            result = delim.join(pynlpir.segment(line, pos_tagging=False))

            result_with_new_line = result + "\n"

            output_lines.append(result_with_new_line)

        output_fd.writelines(output_lines)


def tokenizer_ltp(input_file, output_file, delim=" "):
    with open(input_file, 'r') as fp, open(output_file, 'w') as output_fd:
        output_lines = []
        for raw_line in fp:
            line = raw_line.strip()
            result = delim.join(segmentor.segment(line))

            result_with_new_line = result + "\n"

            output_lines.append(result_with_new_line)

        output_fd.writelines(output_lines)



import os
import subprocess

from tokenizers_collection import ltp_data_base_dir
from tokenizers_collection.download_then_unzip import download_extract_zip


def post_install_action():
    # download the latest license for nlpir
    subprocess.call("pynlpir update", shell=True)

    if not os.path.exists(ltp_data_base_dir):
        os.mkdir(ltp_data_base_dir)

    if not os.path.isdir(ltp_data_base_dir):
        raise Exception("{} must be a directory".format(ltp_data_base_dir))

    download_extract_zip(
        'http://ospm9rsnd.bkt.clouddn.com/model/ltp_data_v3.4.0.zip',
        ltp_data_base_dir
    )


def get_ltp_data_file():
    for root, dirs, files in os.walk(ltp_data_base_dir, topdown=False):
        if 'cws.model' in files:
            return os.path.join(root, 'cws.model')

    raise Exception("Not found 'cws.model' in {}".format(ltp_data_base_dir))


if __name__ == "__main__":
    post_install_action()



# -*- coding: utf-8 -*-

"""Top-level package for Chinese Tokenzier iterator."""
import os

__author__ = """Xiaoquan Kong"""
__email__ = 'u1mail2me@gmail.com'
__version__ = '0.1.1'

ltp_data_base_dir = os.path.join(os.environ.get("HOME"), '.ltp_data')


